@@ -1,7 +1,7 @@
 """
 Type annotations for evidently service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_evidently/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_evidently/literals/)
 
 Usage::
 
@@ -40,8 +40,11 @@ __all__ = (
     "ListProjectsPaginatorName",
     "ProjectStatusType",
     "VariationValueTypeType",
+    "CloudWatchEvidentlyServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -73,6 +76,7 @@ ListLaunchesPaginatorName = Literal["list_launches"]
 ListProjectsPaginatorName = Literal["list_projects"]
 ProjectStatusType = Literal["AVAILABLE", "UPDATING"]
 VariationValueTypeType = Literal["BOOLEAN", "DOUBLE", "LONG", "STRING"]
+CloudWatchEvidentlyServiceName = Literal["evidently"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -104,6 +108,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -190,6 +195,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -226,6 +232,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -374,4 +381,27 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_experiments", "list_features", "list_launches", "list_projects"]
+RegionName = Literal[
+    "ap-northeast-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-west-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-2",
+]
